@@ -1,7 +1,5 @@
 # coding=utf-8
 from .main import *  # noqa
-from ..utils import file_util as fu
-import json
 from .client import PQDataClient
 from ..version import __version__, version_info  # noqa
 from .utils import *  # noqa
@@ -32,13 +30,6 @@ def get(url, params=None, data=None, json=None, **kwargs):
     return PQDataClient.instance().request(method='get', url=url, params=params, data=data, json=json, **kwargs)
 
 
-# 登录
-config_file = 'config.sdk.json'
-if fu.check_path_exists(config_file):
-    with open(config_file, 'r', encoding='utf-8') as f:
-        sdk_config = json.loads(f.read())
-    auth_by_token(token=sdk_config['token'], host=sdk_config['host'], audience=sdk_config['audience'])
-
 __all__ = [
     "auth",
     "auth_by_token",
