@@ -26,10 +26,11 @@ else:
 
 
 class PQDataClient(object):
-    _threading_local = threading.local()
+    _lock = threading.Lock()  # 类级别的锁，用于线程安全
+    _instances = {}  # 类级别的字典，用于存储单例实例
     _auth_params = {}
 
-    _default_host = "101.132.62.72"
+    _default_host = "api.pinkquant.com"
     _default_port = 7500
 
     request_timeout = 300
@@ -70,7 +71,7 @@ class PQDataClient(object):
     def set_auth_params(cls, **params):
         if params != cls._auth_params and cls.instance():
             cls.instance()._reset()
-            cls._threading_local._instance = None
+            cls._instances['_instance'] = None
         cls._auth_params = params
         cls.instance().ensure_auth()
 
@@ -126,7 +127,7 @@ class PQDataClient(object):
         auth_message = zlib.decompress(response.msg).decode('utf-8')
 
         if not response.status:
-            self._threading_local._instance = None
+            self._instances['_instance'] = None
             raise self.get_error(response)
         else:
             if self.not_auth:
@@ -152,14 +153,13 @@ class PQDataClient(object):
 
     @classmethod
     def instance(cls):
-        _instance = getattr(cls._threading_local, '_instance', None)
-        print(f"==================== _instance not in cls._threading_local, _instance={_instance}")
-
-        if _instance is None:
-            if cls._auth_params:
-                _instance = PQDataClient(**cls._auth_params)
-            cls._threading_local._instance = _instance
-        return _instance
+        with cls._lock:
+            _instance = cls._instances.get('_instance', None)
+            if _instance is None:
+                if cls._auth_params:
+                    _instance = PQDataClient(**cls._auth_params)
+                cls._instances['_instance'] = _instance
+            return _instance
 
     def query(self, method, params):
         params["timeout"] = self.request_timeout
@@ -199,13 +199,21 @@ class PQDataClient(object):
             ))
         return result["msg"]
 
-    def __call__(self, method, **kwargs):
+    def __call__(self, method, *args, **kwargs):
         err, result = None, None
+        max_retry = args[0] if len(args) > 0 else self.request_attempt_count  # 最多尝试次数
+        result_on_except = args[1] if len(args) > 1 else None  # 如果尝试失败的返回默认结果
+        retry_count = 0
         for _ in range(self.request_attempt_count):
+            retry_count += 1
             try:
                 result = self.query(method, kwargs)
                 break
             except socket_error as ex:
+                # 达到最大重试次数，返回异常时的默认结果
+                if retry_count >= max_retry:
+                    return result_on_except
+
                 if not self._ping_server():
                     self._reset()
                 err = ex
@@ -219,7 +227,12 @@ class PQDataClient(object):
         return self.convert_message(result)
 
     def __getattr__(self, method):
-        return lambda **kwargs: self(method, **kwargs)
+        # 创建一个闭包来捕获 name，并返回一个新的函数，该函数接受 *args 和 **kwargs
+        def method_wrapper(*args, **kwargs):
+            return self(method, *args, **kwargs)
+
+            # 返回闭包
+        return method_wrapper
 
     def _ping_server(self):
         if not self.client or not self.inited:
