@@ -1,7 +1,14 @@
 # coding=utf-8
+from thriftpy2.transport import TTransportException
+
 from .client import PQDataClient
 from .utils import *
 from typing import Union, List
+import time
+from ..logger import log
+import pandas as pd
+# 使用LRU缓存减少数据库查询
+from functools import lru_cache
 
 
 class GlobalObject(object):
@@ -42,11 +49,13 @@ def get_factor(sec_code: Union[None, str, List[str]] = None,
                dividend_type: str = 'front',
                unit: str = '1d',
                expect_df: bool = True,
-               count: int = None):
+               count: int = None,
+               fill_data: bool = False):
     """
     查询因子库数据.
 
 
+    :param fill_data: bool 是否向后填充空缺数据, 目前支持unit = '1d'
     :param sec_code: 股票代码，支持字符串或者字符串数组. 为数组的时候等价于sec_code_list
     :param factor: 因子名称, 支持字符串或者字符串数组，为数组的时候，等价于factor_list
     :param sec_code_list: 股票代码列表
@@ -69,7 +78,7 @@ def get_factor(sec_code: Union[None, str, List[str]] = None,
                 : 后复权
     :param unit: 单位时间长度，支持1d、1m，默认为1d
     :param expect_df: 是否以DataFrame返回
-    :param count: 数量, 返回的结果集的行数
+    :param count: 数量, 返回最近的条目数
     :return:
     """
     if factor_list is None:
@@ -258,6 +267,7 @@ def get_synthesize_portfolio(count: int = None,
 
 
 @assert_auth
+@lru_cache(maxsize=1024)
 def get_trade_cal(start_date: str = '2018-01-01'):
     """
     获取交易日历，默认从2018-01-01开始
@@ -267,6 +277,7 @@ def get_trade_cal(start_date: str = '2018-01-01'):
 
 
 @assert_auth
+@lru_cache(maxsize=1024)
 def get_previous_trading_date(date: str, lookback_days: int = 1):
     """
     对于给定的日期，返回前第n天
@@ -278,6 +289,7 @@ def get_previous_trading_date(date: str, lookback_days: int = 1):
 
 
 @assert_auth
+@lru_cache(maxsize=1024)
 def get_next_trading_date(date: str, lookahead_days: int = 1):
     """
     对于给定的日期，返回后第n天
@@ -289,17 +301,33 @@ def get_next_trading_date(date: str, lookahead_days: int = 1):
 
 
 @assert_auth
-def get_near_trade_date(trade_date: str):
+@lru_cache(maxsize=1024)
+def get_near_trade_date(trade_date: str, max_retries=5, retry_delay=2):
     """
-    检查trade_date是否为交易日，否则，获取上一个交易日
+    检查trade_date是否为交易日，否则，获取上一个交易日。
+    如果返回值不是字符串类型，则重试，最多重试max_retries次，每次间隔retry_delay秒。
 
-    :param trade_date:
-    :return:
+    :param trade_date: 输入的交易日期
+    :param max_retries: 最大重试次数
+    :param retry_delay: 每次重试之间的延迟时间（秒）
+    :return: 最近的交易日（字符串类型）
     """
-    return PQDataClient.instance().get_near_trade_date(**locals())
+    retries = 0
+    while retries < max_retries:
+        res = PQDataClient.instance().get_near_trade_date(trade_date=trade_date)
+        if isinstance(res, str):
+            return res
+        else:
+            log.warning(f"返回值不是字符串类型，{res}，重试 {retries + 1}/{max_retries}...")
+            retries += 1
+            time.sleep(retry_delay)
+
+            # 如果达到最大重试次数仍然失败，可以抛出一个异常或返回一个默认值
+    raise ValueError("无法获取有效的交易日期，已达到最大重试次数")
 
 
 @assert_auth
+@lru_cache(maxsize=1024)
 def get_open_trade_dates(start_date: str, end_date: str = None):
     """
     通过开始日期和结束日期，取得交易日。
@@ -445,6 +473,7 @@ def get_stock_name_his(sec_code: str, trade_date: str):
 
 
 @assert_auth
+@lru_cache(maxsize=1024)
 def is_open_trade_date(date: str):
     """检查是否为交易日"""
     return PQDataClient.instance().is_open_trade_date(**locals())
@@ -488,6 +517,20 @@ def get_plate_data(trade_date: str = None, end_time: str = "15:00", limit: int =
     return PQDataClient.instance().get_plate_data(**locals())
 
 
+@assert_auth
+def get_hot_plate(trade_date: str = None, n_days: int = 5, top_n: int = 5, hot_n: int = 5, exclude_list: list = None):
+    """
+    获取最近n天 上榜(每天进入强度前n)天数最多的板块
+    :param trade_date: 选股日期, 默认为前一个交易日
+    :param n_days: 从最近多少天里筛选热门板块，默认 5
+    :param top_n:  每天热度top n，默认top 5
+    :param hot_n:  最终选出 最近n_days 天 热门的前n个板块
+    :param exclude_list: 排除的板块清单，比如 ST板块，中报增长板块等
+    :return: DataFrame
+    """
+    return PQDataClient.instance().get_hot_plate(**locals())
+
+
 @assert_auth
 def get_plate_members_lst(plate_code_list: list, trade_date: str = None):
     """
@@ -499,6 +542,29 @@ def get_plate_members_lst(plate_code_list: list, trade_date: str = None):
     return PQDataClient.instance().get_plate_members_lst(**locals())
 
 
+@assert_auth
+def get_member_plates(sec_code: str, trade_date: str = None) -> pd.DataFrame:
+    """
+    获取股票代码所属的板块, 一个股票可能属于多个板块。除了获取板块外，额外提供板块强度，并且按照板块强度倒序排列。
+    :param sec_code: 股票代码
+    :param trade_date: 交易日，不同交易下的板块可能不同
+    :return: DataFrame， 字段包括 板块代码，板块名称，板块强度
+           plate_code plate_name  intensity
+    0      801660         通信       2306
+    1      801250       并购重组       1834
+    2      801218       华为概念       1610
+    3      801328       消费电子        640
+    4      801001         芯片        456
+    5      801878       端侧AI        296
+    6      801408       智能家居        246
+    7      801519        汽车类        227
+    8      801857      PPP概念        136
+    9      801033       国有企业         44
+    10     801382     分拆上市预期         38
+    """
+    return PQDataClient.instance().get_member_plates(**locals())
+
+
 @assert_auth
 def get_stock_name(sec_code: str, trade_date: str = None):
     """
@@ -616,6 +682,119 @@ def get_suspend_status(sec_code: str, trade_date: str = None):
     return PQDataClient.instance().get_suspend_status(**locals())
 
 
+@assert_auth
+def get_prompt_query(query: str,
+                     query_type: str = 'stock',
+                     page_num: int = None,
+                     page_size: int = None,
+                     loop: Union[bool, int] = False):
+    """
+    通过Prompt Query的方式进行选股。
+    举例：2024-10-16,DDE大单净量>0.25, 非科创板,非创业板,非北交所,非ST
+    将获取相关的股票列表：
+        ['002793.SZ', '000838.SZ', '600837.SH', '000972.SZ', '600889.SH', ...]
+
+    :param query: 通过文本的方式进行选股
+    :param query_type: 支持: stock: 股票，fund: 基金
+    :param page_num: 可选，查询的页号，默认为1
+    :param page_size: 可选，每页行数, 最小50， 最大100，默认为100
+    :param loop: 是否循环分页，返回多页合并数据。默认值为False，可以设置为True或具体数值. 当为数值的时候，1-n的多页数据一起返回
+    :return: list, 股票代码列表
+    """
+    params_dict = {"query": query,
+                   "query_type": query_type,
+                   "page_size": page_size,
+                   }
+
+    if page_num and loop is False:
+        params_dict['page_num'] = page_num
+        max_retry = 2  # 最多尝试次数
+        result_on_except = []  # 如果尝试失败的返回默认结果
+        return PQDataClient.instance().get_prompt_query(*(max_retry, result_on_except), **params_dict)
+
+    elif isinstance(loop, bool) and loop is True:  # 分页查询，最终合并结果
+        _page_num = 1
+        result = []
+        while True:
+            params_dict['page_num'] = _page_num
+            max_retry = 2  # 最多尝试次数
+            result_on_except = []  # 如果尝试失败的返回默认结果
+            stock_list = PQDataClient.instance().get_prompt_query(*(max_retry, result_on_except), **params_dict)
+            result.extend(stock_list)
+            _page_num += 1
+            if len(stock_list) == 0:
+                break
+        return result
+    elif isinstance(loop, int):  # 返回前x页
+        loop = max(1, loop)
+        params_dict['loop'] = loop
+        return PQDataClient.instance().get_prompt_query(**params_dict)
+    else:
+        return PQDataClient.instance().get_prompt_query(**params_dict)
+
+
+@assert_auth
+def get_reduce_holdings(start_date: str, end_date: str):
+    """
+    获取指定日期范围内发布了减持公告的股票代码列表
+
+    :param start_date: 开始日期
+    :param end_date: 结束日期
+    :return: list，股票代码列表
+    """
+    return PQDataClient.instance().get_reduce_holdings(**locals())
+
+
+@assert_auth
+def get_board_members(boards: list,
+                      status: str = "L",
+                      start_date: str = None,
+                      end_date: str = None,
+                      is_hs: str = None):
+    """
+    获取板块的成分股
+
+    :param boards: 板块列表
+            [
+            "sz.zh", # 深市主板
+            "sh.zh", # 沪市主板
+            "sz.cy", # 创业板
+            "sh.kc", # 科创板
+            "sz.zx",  # 中小板
+            "bj.bj",  # 北交所
+            ]
+    :param status: 上市状态 L上市 D退市 P暂停上市
+    :param start_date: # 上市日期范围
+    :param end_date: # 上市日期范围
+    :param is_hs: 是否沪深港通标的，N否 H沪股通 S深股通
+    :return: list, 股票列表
+    """
+    return PQDataClient.instance().get_board_members(**locals())
+
+
+@assert_auth
+@lru_cache(maxsize=1024)
+def get_up_limit_stocks(stock_list: list, trade_date: str, lookback_days: int = 1, dividend_type: str = 'front'):
+    """
+    获取连板涨停的股票列表。
+
+    :param dividend_type: 复权选项(对股票/基金的价格字段、成交量字段及factor字段生效)
+                'front'
+                : 前复权, 默认是前复权
+                none
+                : 不复权, 返回实际价格
+                'back'
+                : 后复权
+    :param stock_list:
+    :param trade_date:
+    :param lookback_days:
+            0：昨日未涨停的股票
+            >=1: 连板涨停的股票
+    :return: list，股票代码列表
+    """
+    return PQDataClient.instance().get_up_limit_stocks(**locals())
+
+
 # ---------------------------------------------------------
 # 外部可以访问的列表
 # ---------------------------------------------------------
