@@ -2,8 +2,9 @@
 from .main import BacktestExecutor
 import pqsdk.utils.file_util as fu
 import json
-import faxdatasdk
+import pqsdk.api as pqdatasdk
 from pqsdk import log
+from pqsdk.api import PQDataClient
 import pandas as pd
 import quantstats as qs
 from pathlib import Path
@@ -11,21 +12,31 @@ import datetime
 import os
 
 
-def execute(parameters: dict, script: str = None, strategy_file: str = None):
-    # 登录faxdatasdk
-    config_file = 'config.sdk.json'
-    if not fu.check_path_exists(config_file):
-        print("未找到配置文件. 请先运行命令进行配置: pqsdk config")
-        exit(-1)
+def execute(parameters: dict, script: str = None, strategy_file: str = None, task=None):
+    """
+    执行回测
+    :param parameters: 回测参数字典
+    :param script: 策略脚本
+    :param strategy_file: 策略脚本文件
+    :param task: celery task
+    :return:
+    """
+    if not PQDataClient.instance() or not PQDataClient.instance().inited:
+        log.debug("登录pqdatasdk服务端点")
+        config_file = 'config.sdk.json'
+        if not fu.check_path_exists(config_file):
+            err_msg = "未找到配置文件. 请先运行命令进行配置: pqsdk config"
+            log.error(err_msg)
+            raise Exception(err_msg)
 
-    with open(config_file, 'r', encoding='utf-8') as f:
-        sdk_config = json.loads(f.read())
-    faxdatasdk.auth_by_token(token=sdk_config['token'], host=sdk_config['host'], audience=sdk_config['audience'])
+        with open(config_file, 'r', encoding='utf-8') as f:
+            sdk_config = json.loads(f.read())
+        pqdatasdk.auth_by_token(token=sdk_config['token'], host=sdk_config['host'], audience=sdk_config['audience'])
 
     if strategy_file:
         strategy_file = os.path.splitext(strategy_file)[0]
     kwargs = {"parameters": parameters, "script": script, "strategy_file": strategy_file}
-    executor = BacktestExecutor(kwargs=kwargs)
+    executor = BacktestExecutor(kwargs=kwargs, task=task)
     results = executor.run()
     return results
 
