@@ -284,7 +284,7 @@ class StrategyContext(AbstractStrategyContext):
                    factor: Union[None, str, List[str]] = None,
                    unit: str = '1d',
                    sec_code_list: list = None,
-                   factor_list: list = ...,
+                   factor_list: list = None,
                    trade_date: str = None,
                    start_date: str = None,
                    end_date: str = None,
@@ -297,7 +297,7 @@ class StrategyContext(AbstractStrategyContext):
         unit= 1d：默认截止到昨日收盘价
         unit= 1m, 5m:默认截止到前1分钟收盘价
 
-        :param count:
+        :param count: 返回最近的条目数
         :param sec_code: 股票代码，支持字符串或者字符串数组. 为数组的时候等价于sec_code_list
         :param factor: 因子名称, 支持字符串或者字符串数组，为数组的时候，等价于factor_list
         :param unit: 单位时间长度，支持1d、1m，默认为1d
@@ -321,11 +321,11 @@ class StrategyContext(AbstractStrategyContext):
         if count is None and start_date is None and trade_date is None:
             raise Exception(f"attribute_history()函数必须指定count, start_date, trade_date之一")
 
-        if sec_code_list is None:
-            sec_code_list = self.run_info.stock_pool_members
+        # if sec_code_list is None:
+        #     sec_code_list = self.run_info.stock_pool_members
 
         # 如果未提供时间范围，且trade_date=None，则默认获取上一个交易日
-        if not start_date and not end_date:
+        if count is None and not start_date and not end_date:
             pre_trade_date = get_previous_trading_date(self.current_dt.strftime('%Y-%m-%d'))
             trade_date = trade_date if trade_date else pre_trade_date
 
@@ -567,6 +567,9 @@ class StrategyContext(AbstractStrategyContext):
         :param limit: 按照板块强度倒序排名的板块数量
         :return:
         """
+        if trade_date is None:
+            trade_date = self.current_dt.strftime('%Y-%m-%d')
+
         return get_plate_data(trade_date=trade_date, end_time=end_time, limit=limit)
 
     def get_plate_members_lst(self, plate_code_list: list, trade_date: str = None):
@@ -576,8 +579,34 @@ class StrategyContext(AbstractStrategyContext):
         :param trade_date:
         :return:
         """
+        if trade_date is None:
+            trade_date = self.current_dt.strftime('%Y-%m-%d')
+            
         return get_plate_members_lst(plate_code_list=plate_code_list, trade_date=trade_date)
 
+    def get_member_plates(self, sec_code: str, trade_date: str = None) -> pd.DataFrame:
+        """
+        获取股票代码所属的板块, 一个股票可能属于多个板块。除了获取板块外，额外提供板块强度，并且按照板块强度倒序排列。
+        :param sec_code: 股票代码
+        :param trade_date: 交易日，不同交易下的板块可能不同
+        :return: DataFrame， 字段包括 板块代码，板块名称，板块强度
+               plate_code plate_name  intensity
+        0      801660         通信       2306
+        1      801250       并购重组       1834
+        2      801218       华为概念       1610
+        3      801328       消费电子        640
+        4      801001         芯片        456
+        5      801878       端侧AI        296
+        6      801408       智能家居        246
+        7      801519        汽车类        227
+        8      801857      PPP概念        136
+        9      801033       国有企业         44
+        10     801382     分拆上市预期         38
+        """
+        if trade_date is None:
+            trade_date = self.current_dt.strftime('%Y-%m-%d')
+        return get_member_plates(sec_code=sec_code, trade_date=trade_date)
+
     def get_stock_name(self, sec_code: str, trade_date: str = None):
         """
         获取股票代码的最新名称
@@ -610,6 +639,8 @@ class StrategyContext(AbstractStrategyContext):
         :param sec_code:
         :return:
         """
+        if trade_date is None:
+            trade_date = self.current_dt.strftime('%Y-%m-%d')
         return get_stock_price(sec_code=sec_code,
                                trade_date=trade_date,
                                end_time=end_time,
@@ -639,10 +670,34 @@ class StrategyContext(AbstractStrategyContext):
         :param trade_date: 指定日期的涨跌停价格
         :return: (昨日收盘价格, 今日涨停价, 今日跌停价)
         """
+        if trade_date is None:
+            trade_date = self.current_dt.strftime('%Y-%m-%d')
+
         return get_price_limit(sec_code=sec_code,
                                trade_date=trade_date,
                                dividend_type=dividend_type)
 
+    def get_prompt_query(self,
+                         query: str,
+                         query_type: str = 'stock',
+                         page_num: int = None,
+                         page_size: int = None,
+                         loop: Union[bool, int] = False):
+        """
+        通过Prompt Query的方式进行选股。
+        举例：2024-10-16,DDE大单净量>0.25, 非科创板,非创业板,非北交所,非ST
+        将获取相关的股票列表：
+            ['002793.SZ', '000838.SZ', '600837.SH', '000972.SZ', '600889.SH', ...]
+
+        :param query: 通过文本的方式进行选股
+        :param query_type: 支持: stock: 股票，fund: 基金
+        :param page_num: 可选，查询的页号，默认为1
+        :param page_size: 可选，每页行数, 最小50， 最大100，默认为100
+        :param loop: 是否循环分页，返回多页合并数据。默认值为False，可以设置为True或具体数值. 当为数值的时候，1-n的多页数据一起返回
+        :return: list, 股票代码列表
+        """
+        return get_prompt_query(query=query, query_type=query_type, page_num=page_num, page_size=page_size, loop=loop)
+
     def get_auction_data(self,
                          security: str,
                          count: int = None,
@@ -663,6 +718,9 @@ class StrategyContext(AbstractStrategyContext):
         :param fields: 获取字段，范围：['open', 'high', 'low', 'close', 'pre_close']
         :return:
         """
+        if trade_date is None:
+            trade_date = self.current_dt.strftime('%Y-%m-%d')
+
         return get_auction_data(security=security,
                                 count=count,
                                 unit=unit,
@@ -920,7 +978,8 @@ class StrategyContext(AbstractStrategyContext):
         """
         # 检查股票是否已经停牌
         if get_suspend_status(sec_code=stock_code, trade_date=self.current_dt.strftime('%Y-%m-%d')) > 0:
-            log.warning(f"股票停牌，取消买入: stock_code={stock_code}, trade_date={self.current_dt.strftime('%Y-%m-%d')}")
+            log.warning(
+                f"股票停牌，取消买入: stock_code={stock_code}, trade_date={self.current_dt.strftime('%Y-%m-%d')}")
             return
 
         # 获取价格
@@ -992,7 +1051,8 @@ class StrategyContext(AbstractStrategyContext):
         """
         # 检查股票是否已经停牌
         if get_suspend_status(sec_code=stock_code, trade_date=self.current_dt.strftime('%Y-%m-%d')) > 0:
-            log.warning(f"股票停牌，取消卖出: stock_code={stock_code}, trade_date={self.current_dt.strftime('%Y-%m-%d')}")
+            log.warning(
+                f"股票停牌，取消卖出: stock_code={stock_code}, trade_date={self.current_dt.strftime('%Y-%m-%d')}")
             return
 
         # 获取价格
