@@ -36,8 +36,6 @@ class BacktestExecutor:
         must_have_params = {'benchmark': "行情基准",
                             'stock_pool': "股票池",
                             'unit': "行情周期",
-                            'adjust_period': "调仓周期",
-                            'hold_maxsize': "最大持仓",
                             "cash": "回测初始资金",
                             'start_date': "回测开始日期",
                             'end_date': "回测结束日期",
