@@ -1,6 +1,6 @@
 from six import with_metaclass
 import abc
-from typing import Callable
+from typing import Callable, Union, List
 from .abstractPosition import AbstractPosition
 from .abstractInstrument import AbstractInstrument
 import datetime
@@ -654,6 +654,28 @@ class AbstractStrategyContext(with_metaclass(abc.ABCMeta)):
         """
         raise NotImplementedError
 
+    @abc.abstractmethod
+    def get_prompt_query(self,
+                         query: str,
+                         query_type: str = 'stock',
+                         page_num: int = None,
+                         page_size: int = None,
+                         loop: Union[bool, int] = False):
+        """
+        通过Prompt Query的方式进行选股。
+        举例：2024-10-16,DDE大单净量>0.25, 非科创板,非创业板,非北交所,非ST
+        将获取相关的股票列表：
+            ['002793.SZ', '000838.SZ', '600837.SH', '000972.SZ', '600889.SH', ...]
+
+        :param query: 通过文本的方式进行选股
+        :param query_type: 支持: stock: 股票，fund: 基金
+        :param page_num: 可选，查询的页号，默认为1
+        :param page_size: 可选，每页行数, 最小50， 最大100，默认为100
+        :param loop: 是否循环分页，返回多页合并数据。默认值为False，可以设置为True或具体数值. 当为数值的时候，1-n的多页数据一起返回
+        :return: list, 股票代码列表
+        """
+        raise NotImplementedError
+
     @abc.abstractmethod
     def get_auction_data(self,
                          security: str,
