@@ -34,6 +34,34 @@ class TimerFactory:
             # 如果不是期望的格式，则返回错误或空字符串
             raise Exception(f"字符串格式不符合: {time_str}, 必须为HH:MM格式，或者HH:MM:SS的格式")
 
+    @classmethod
+    def is_valid_time(cls, start_time, t, interval: int, unit: str = 'm'):
+        """
+        判断给定时间t是否大于或等于开始时间start_time，并且t是以n个unit做为间隔的
+
+        :param start_time: 检查的起始时间，datetime.datetime类型
+        :param t: 被检查的时间，datetime.datetime类型
+        :param interval: 单位间隔
+        :param unit: 单位
+        :return: bool
+        """
+
+        if unit not in ['m', 's']:
+            raise Exception("unit is wrong, must be 'm' for minutes, or 's' for second.")
+        # 确保t不小于start_time
+        if t < start_time:
+            return False
+
+            # 计算t和start_time之间的时间差
+        time_diff = t - start_time
+
+        # 将时间差转换为分钟，并检查是否为n分钟的整数倍
+        if unit == 'm':
+            minutes_diff = time_diff.total_seconds() // 60  # 转换为分钟
+        else:
+            minutes_diff = time_diff.total_seconds()
+        return minutes_diff % interval == 0
+
     def add_timer(self,
                   callback: Callable,
                   kwargs,
@@ -43,6 +71,8 @@ class TimerFactory:
                   monthdays=None,
                   monthcarry=True,
                   dates=None,
+                  minutes=None,
+                  seconds=None,
                   datecarry=True):
         """
         添加计时器
@@ -55,6 +85,8 @@ class TimerFactory:
         :param monthdays: 每月的第几天运行
         :param monthcarry: 为非交易日，是否顺延下一个交易日
         :param dates: 间隔天数执行的日期列表，start_date为第一次执行日期
+        :param minutes: 以when作为时间起点, 间隔的分神数执行
+        :param seconds: 以when作为时间起点, 间隔的秒数执行
         :param datecarry: 为非交易日，是否顺延下一个交易日
         :return:
         """
@@ -78,6 +110,8 @@ class TimerFactory:
                      monthdays=monthdays,
                      monthcarry=monthcarry,
                      dates=dates,
+                     minutes=minutes,
+                     seconds=seconds,
                      datecarry=datecarry
                      )
         self.timer_list.append(timer)
@@ -157,6 +191,28 @@ class TimerFactory:
             if len(dates) > 0 and current_date not in dates:
                 continue
 
-            # 执行回调函数, 如果是基准周期是1d则直接放行，如果是1m或者5m，则时间到达后执行
-            if self.unit in ['1d'] or current_dt.strftime('%H:%M:%S') == timer['when']:
+            # 执行回调函数的时机
+            if self.unit in ['1d']:  # 日行情，每日执行
+                # 如果是基准周期(self.unit)是1d则直接放行
+                callback(**kwargs)
+            elif self.unit in ['1m', '5m'] and timer['minutes'] is not None:  # 每间隔n分钟执行
+                # 如果基准周期(self.unit)是1m或者5m, 间隔n分钟后执行
+                start_time_str = f"{current_dt.strftime('%Y-%m-%d')} {timer['when']}"
+                start_time = datetime.datetime.strptime(start_time_str, "%Y-%m-%d %H:%M:%S")
+                if self.is_valid_time(start_time=start_time, t=current_dt, interval=timer['minutes'], unit='m'):
+                    callback(**kwargs)
+            elif self.unit in ['1m', '5m'] and timer['seconds'] is not None:  # 每间隔n秒执行
+                # 如果基准周期(self.unit)是1m或者5m, 间隔n秒后执行
+
+                # TODO 因为还没有秒级的行情数据，当秒级间隔时直接放行，否则使用下方注释掉的逻辑
+                callback(**kwargs)
+
+                # TODO 临时注释掉的逻辑，直到有秒级的数据
+                # start_time_str = f"{current_dt.strftime('%Y-%m-%d')} {timer['when']}"
+                # start_time = datetime.datetime.strptime(start_time_str, "%Y-%m-%d %H:%M:%S")
+                # if self.is_valid_time(start_time=start_time, t=current_dt, interval=timer['seconds'], unit='s'):
+                #     callback(**kwargs)
+
+            elif self.unit in ['1m', '5m'] and current_dt.strftime('%H:%M:%S') == timer['when']:  # 分钟行情，指定时间执行
+                # 如果基准周期(self.unit)是1m或者5m，则时间到达后执行
                 callback(**kwargs)
